#!/usr/bin/env python
import os
import sys
sys.path.insert(0, os.path.abspath('..'))

import nidhoggr_requests

extensions = ['sphinx.ext.autodoc', 'sphinx.ext.viewcode']

templates_path = ['_templates']
source_suffix = '.rst'

master_doc = 'index'

project = 'nidhoggr-requests'
copyright = "2019, Roman Shishkin"
author = "Roman Shishkin"

version = nidhoggr_requests.__version__
release = nidhoggr_requests.__version__

language = None
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

pygments_style = 'sphinx'

todo_include_todos = False

html_theme = 'alabaster'

html_theme_options = {
    "fixed_sidebar": True,
    "page_width": "60%"
}

# html_static_path = ['_static']

htmlhelp_basename = 'nidhoggr_requests_doc'



import requests
from typing import Dict, Optional
from nidhoggr.bl import BaseUserRepo, User


class RequestsUserRepo(BaseUserRepo):
    def __init__(self, api_url: str, bearer_token: str):
        self.api_url = api_url
        self.bearer_token = bearer_token

    def get_user(self, **kw: Dict[str, str]) -> Optional[User]:
        result = requests.post(f'{self.api_url}/user/get', json=kw, headers={
            'Authorization': f'Bearer {self.bearer_token}',
            'Content-Type': 'application/json'
        })

        if result.status_code != 200:
            return None

        result_json = result.json()
        if not result_json:
            return None

        return User.parse_obj(result_json)

    def check_password(self, *, clean: str, uuid: str) -> bool:
        result = requests.post(f'{self.api_url}/user/check_password', json={'uuid': uuid, 'password': clean}, headers={
            'Authorization': f'Bearer {self.bearer_token}',
            'Content-Type': 'application/json'
        })

        if result.status_code != 200:
            return False

        result_json = result.json()
        if 'authenticated' not in result_json:
            return False

        return result_json['authenticated']

    def save_user(self, *, user: User) -> bool:
        result = requests.post(f'{self.api_url}/user/save', json=user.dict(), headers={
            'Authorization': f'Bearer {self.bearer_token}',
            'Content-Type': 'application/json'
        })

        if result.status_code != 200:
            return False

        result_json = result.json()
        if 'saved' not in result_json:
            return False

        return result_json['saved']



from pkg_resources import get_distribution, DistributionNotFound
import os.path

try:
    _dist = get_distribution('nidhogg_requests')
    dist_loc = os.path.normcase(_dist.location)
    here = os.path.normcase(__file__)
    if not here.startswith(os.path.join(dist_loc, 'nidhogg_requests')):
        raise DistributionNotFound
except DistributionNotFound:
    __version__ = 'Please install this project with setup.py'
else:
    __version__ = _dist.version



import requests
from typing import Dict

from nidhoggr.bl import BaseTextureRepo
from nidhoggr.models.texture import TextureType, TextureItem


class RequestsTextureRepo(BaseTextureRepo):
    def __init__(self, api_url: str, bearer_token: str):
        self.api_url = api_url
        self.bearer_token = bearer_token

    def get(self, *, uuid: str) -> Dict[TextureType, TextureItem]:
        result = requests.post(f'{self.api_url}/texture/get', json={'uuid': uuid}, headers={
            'Authorization': f'Bearer {self.bearer_token}',
            'Content-Type': 'application/json'
        })

        if result.status_code != 200:
            return {}

        result_json = result.json()
        if not result_json:
            return {}

        response = {}
        for texture in result_json:
            response[TextureType(texture)] = TextureItem(url=result_json[texture])

        return response
